@@ -3,9 +3,9 @@ var searchData=
   ['tan',['tan',['../a00454.html#ac96b7a51e7ac1923b3b1d1e85fbff53b',1,'rtl::math']]],
   ['terminate',['terminate',['../a00194.html#af7ffa642d68ae530bc76b12ca5852ca6',1,'osl::Thread']]],
   ['thread',['Thread',['../a00193.html#a1b544964df8448966d54099c5ecf2918',1,'salhelper::Thread::Thread()'],['../a00194.html#a354d6ff717692c854543da069c493a6a',1,'osl::Thread::Thread()']]],
-  ['threaddata',['ThreadData',['../a00195.html#a5a9888207e55caddd0ac911fb5fbbb8b',1,'osl::ThreadData']]],
+  ['threaddata',['ThreadData',['../a00195.html#a3fac11314cd8ba1fb612a8ccf844d5cc',1,'osl::ThreadData']]],
   ['threadfunc',['threadFunc',['../a00451.html#a919fa4231771ea453e5996b0e288807a',1,'osl']]],
-  ['throwexception',['throwException',['../a00303.html#adcab1896daab37b2838df68d5c54adbb',1,'cppu']]],
+  ['throwexception',['throwException',['../a00303.html#ab48786c964739bb4afd274eb637dce5e',1,'cppu']]],
   ['timedout',['timedout',['../a00196.html#ad660f435988878cc089e7a5835703c66',1,'salhelper::ConditionWaiter::timedout::timedout()'],['../a00196.html#af7d5cc7e5c516a587e06fdc9c3e7c636',1,'salhelper::ConditionWaiter::timedout::timedout(timedout const &amp;)']]],
   ['timer',['Timer',['../a00197.html#acdd49db9d293bbc30672ea2858bc3b85',1,'salhelper::Timer::Timer()'],['../a00197.html#a1d857a42398e461242c0f9082e6eaa9e',1,'salhelper::Timer::Timer(const TTimeValue &amp;Time)'],['../a00197.html#a3998be53d29e0709c891a1939ec45c23',1,'salhelper::Timer::Timer(const TTimeValue &amp;Time, const TTimeValue &amp;RepeatTime)']]],
   ['toany',['toAny',['../a00268.html#aa96d250594e70eadc0181a2f7082772b',1,'com::sun::star::uno::toAny(T const &amp;value)'],['../a00268.html#a80d03f5ef676c2eadc725ffcebecc19a',1,'com::sun::star::uno::toAny(Any const &amp;value)']]],
@@ -17,6 +17,7 @@ var searchData=
   ['tofloat',['toFloat',['../a00148.html#a0a3af99714b9c6146cd8ffb3ebfb22d9',1,'rtl::OString::toFloat()'],['../a00152.html#a2fd066e4c1036c780468521ebae0fea8',1,'rtl::OUString::toFloat()']]],
   ['toint32',['toInt32',['../a00148.html#a033da0eb6b38c955d94877df5347794b',1,'rtl::OString::toInt32()'],['../a00152.html#a40cdf4e23a5c1cf9028fbd9794c4f32e',1,'rtl::OUString::toInt32()']]],
   ['toint64',['toInt64',['../a00148.html#a5a51db6d09f140de2c91871baca775a3',1,'rtl::OString::toInt64()'],['../a00152.html#a92834cbad1c62cbdc7f82803d17ae521',1,'rtl::OUString::toInt64()']]],
+  ['topointer',['toPointer',['../a00068.html#a3b85532ef23d957360c17cead75cde0a',1,'rtl::libreoffice_internal::ConstCharArrayDetector&lt; const char[N], T &gt;']]],
   ['tostring',['toString',['../a00149.html#adbf70a3873d4e702fc8c68cab920dea5',1,'rtl::OStringBuffer::toString()'],['../a00153.html#aebd29db9c1b67653ca54d6b6b185b5fc',1,'rtl::OUStringBuffer::toString()']]],
   ['touint32',['toUInt32',['../a00148.html#a10ce74f5a8ea906e6ea5bb28a4b2f1c7',1,'rtl::OString::toUInt32()'],['../a00152.html#a4c2be479f24280101eda8f7169063cb5',1,'rtl::OUString::toUInt32()']]],
   ['touint64',['toUInt64',['../a00148.html#accc09868ce8399e269544d84b71bae51',1,'rtl::OString::toUInt64()'],['../a00152.html#a4dc3e8bea606ad9105ed8b64aa15f80c',1,'rtl::OUString::toUInt64()']]],
@@ -27,7 +28,7 @@ var searchData=
   ['trytoacquire',['tryToAcquire',['../a00130.html#afb75796aa4854379ad4618922c91562f',1,'osl::Mutex']]],
   ['ttimevalue',['TTimeValue',['../a00199.html#ae4c1362936923b2d7eb2f3bc843469f5',1,'salhelper::TTimeValue::TTimeValue()'],['../a00199.html#a9557145962e72ae22232fafe8d8195fe',1,'salhelper::TTimeValue::TTimeValue(sal_uInt32 Secs, sal_uInt32 Nano)'],['../a00199.html#a6e75ce9497b450b51ecf660e3d459dda',1,'salhelper::TTimeValue::TTimeValue(sal_uInt32 MilliSecs)'],['../a00199.html#af3b7a10619e5f2b0465fceab2186ff63',1,'salhelper::TTimeValue::TTimeValue(const TTimeValue &amp;rTimeValue)'],['../a00199.html#a5ca3f5190548d6c6fcb4fba8cbb01837',1,'salhelper::TTimeValue::TTimeValue(const TimeValue &amp;rTimeValue)']]],
   ['type',['Type',['../a00200.html#a89ffc2ae6bdf545544e69eaa7bfa5552',1,'com::sun::star::uno::Type::Type()'],['../a00200.html#a5ebb5b568d42adc4eae85a211c06179e',1,'com::sun::star::uno::Type::Type(TypeClass eTypeClass, const ::rtl::OUString &amp;rTypeName)'],['../a00200.html#a05f3ef0e503946f95db1245a4e0a76af',1,'com::sun::star::uno::Type::Type(TypeClass eTypeClass, const sal_Char *pTypeName)'],['../a00200.html#ac7baba5c6dc7c52f4df3bdb15c26dd7e',1,'com::sun::star::uno::Type::Type(typelib_TypeDescriptionReference *pType)'],['../a00200.html#ab1bad8d7c5cde72f63b71388e8e1b2ff',1,'com::sun::star::uno::Type::Type(typelib_TypeDescriptionReference *pType, UnoType_NoAcquire dummy)'],['../a00200.html#a763a9f04707895b340777c34e70d6ad0',1,'com::sun::star::uno::Type::Type(typelib_TypeDescriptionReference *pType, __sal_NoAcquire dummy)'],['../a00200.html#a7c800af2c1fb97312da44f942dc62459',1,'com::sun::star::uno::Type::Type(const Type &amp;rType)']]],
-  ['typedescription',['TypeDescription',['../a00201.html#aaf318edb725036458361fd3f5f66e6f7',1,'com::sun::star::uno::TypeDescription::TypeDescription(typelib_TypeDescription *pTypeDescr=0)'],['../a00201.html#af3ec54e72f35fc8f1332b9b4923e91d0',1,'com::sun::star::uno::TypeDescription::TypeDescription(typelib_TypeDescriptionReference *pTypeDescrRef)'],['../a00201.html#a6bd7bd715ffd412d62d70271399d4a56',1,'com::sun::star::uno::TypeDescription::TypeDescription(const ::com::sun::star::uno::Type &amp;rType)'],['../a00201.html#af296ca0324da748b0e0bce8e9958a059',1,'com::sun::star::uno::TypeDescription::TypeDescription(const TypeDescription &amp;rDescr)'],['../a00201.html#a2f7fa47976e3fa073add0ca0d7c44903',1,'com::sun::star::uno::TypeDescription::TypeDescription(rtl_uString *pTypeName)'],['../a00201.html#af7fe6f21c3438c12db6aa143e5a2061b',1,'com::sun::star::uno::TypeDescription::TypeDescription(const ::rtl::OUString &amp;rTypeName)']]],
+  ['typedescription',['TypeDescription',['../a00201.html#a01de1d723d0abe7d8d9757075d0f122f',1,'com::sun::star::uno::TypeDescription::TypeDescription(typelib_TypeDescription *pTypeDescr=NULL)'],['../a00201.html#af3ec54e72f35fc8f1332b9b4923e91d0',1,'com::sun::star::uno::TypeDescription::TypeDescription(typelib_TypeDescriptionReference *pTypeDescrRef)'],['../a00201.html#a86456d867afceba7bf1db38e179a1b87',1,'com::sun::star::uno::TypeDescription::TypeDescription(const css::uno::Type &amp;rType)'],['../a00201.html#af296ca0324da748b0e0bce8e9958a059',1,'com::sun::star::uno::TypeDescription::TypeDescription(const TypeDescription &amp;rDescr)'],['../a00201.html#a2f7fa47976e3fa073add0ca0d7c44903',1,'com::sun::star::uno::TypeDescription::TypeDescription(rtl_uString *pTypeName)'],['../a00201.html#af7fe6f21c3438c12db6aa143e5a2061b',1,'com::sun::star::uno::TypeDescription::TypeDescription(const ::rtl::OUString &amp;rTypeName)']]],
   ['typelib_5fsetcachesize',['typelib_setCacheSize',['../a00421.html#af9605511a417960160e304cfb5cd36a2',1,'typedescription.h']]],
   ['typelib_5fstatic_5fcompound_5ftype_5finit',['typelib_static_compound_type_init',['../a00421.html#a191289d22a2687b56296538906b24c81',1,'typedescription.h']]],
   ['typelib_5fstatic_5fenum_5ftype_5finit',['typelib_static_enum_type_init',['../a00421.html#a3ebbf5d81311a477b27b1ebdf93189ca',1,'typedescription.h']]],
